#!/usr/bin/perl
#
# Build script for Test::Stanford distribution.
#
# Written by Russ Allbery <rra@stanford.edu>
# Copyright 2013
#     The Board of Trustees of the Leland Stanford Junior University
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

use 5.010;
use strict;
use warnings;

use File::Copy qw(copy);
use Module::Build;

# Basic package configuration.
my $build = Module::Build->new(
    module_name          => 'Test::Stanford::IDG',
    dist_abstract        => 'Modules for testing Stanford IDG Perl scripts',
    dist_author          => 'Russ Allbery <rra@stanford.edu>',
    dist_version         => '1.00',
    license              => 'mit',
    recursive_test_files => 1,

    # Module static data files.
    share_dir =>
      { module => { 'Test::Stanford::IDG::Critic' => ['share/critic'] } },

    # Other package relationships.
    configure_requires => { 'Module::Build' => 0.36 },
    requires           => {
        'Perl::Critic'       => 0,
        'Test::Perl::Critic' => 0,
        perl                 => '5.010',
    },
);

# Generate the build script.
$build->create_build_script;
